@@ -4,7 +4,8 @@
 import os, sys, json
 
 
-def main(args):
+def main():
+    args, _ = get_args()
     if args.version:
         from .__version__ import __version__
         print(__version__)
@@ -22,5 +23,4 @@ def get_args():
 
 
 if __name__ == '__main__':
-    args, _ = get_args()
-    main(args)
+    main()
